@@ -1,7 +1,7 @@
 /*
- * Cobham Gaisler GRSPW2 SpaceWire Kernel Library Interface.
+ * Frontgrade Gaisler GRSPW2 SpaceWire Kernel Library Interface.
  *
- * Copyright (c) 2016-2022 Cobham Gaisler AB
+ * Copyright (c) 2016-2023 Frontgrade Gaisler AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -37,6 +37,7 @@
 #include <linux/of_irq.h>
 #include <linux/of_platform.h>
 #include <linux/dma-mapping.h>
+#include <linux/clk.h>
 
 #ifdef CONFIG_SPARC_LEON
 #include <asm/leon.h>
@@ -2631,6 +2632,7 @@ static int grspw_of_probe(struct platform_device *of_dev)
 {
 	struct device_node *onp = of_dev->dev.of_node;
 	struct grspw_priv *priv;
+	struct clk *clk;
 	int i, size, err, len;
 	unsigned int ctrl;
 	const int *pampopts, *pversion, *pindex, *pdevice;
@@ -2666,6 +2668,14 @@ static int grspw_of_probe(struct platform_device *of_dev)
 		goto error;
 	}
 
+	/* Enable clock gate (ignore if it does not exist) */
+	clk = devm_clk_get_optional_enabled(&of_dev->dev, "gate");
+	if (IS_ERR(clk)) {
+		dev_err(&of_dev->dev, "failed to enable clk\n");
+		err = PTR_ERR(clk);
+		goto error;
+	}
+
 	/* Get IRQ number of GRSPW device */
 	priv->irq = irq_of_parse_and_map(onp, 0);
 	if (!priv->irq) {
@@ -2878,7 +2888,7 @@ static void __exit grspw_exit (void)
 module_init(grspw_init);
 module_exit(grspw_exit);
 
-MODULE_AUTHOR("Cobham Gaisler AB.");
-MODULE_DESCRIPTION("Cobham Gaisler GRSPW SpaceWire Library");
+MODULE_AUTHOR("Frontgrade Gaisler AB.");
+MODULE_DESCRIPTION("Frontgrade Gaisler GRSPW SpaceWire Library");
 MODULE_LICENSE("GPL");
 MODULE_ALIAS("platform:grlib-grspw");
