@@ -1,7 +1,7 @@
 /*
- * Cobham Gaisler GRSPW user space access Driver.
+ * Frontgrade Gaisler GRSPW user space access Driver.
  *
- * Copyright (c) 2016-2022 Cobham Gaisler AB
+ * Copyright (c) 2016-2023 Frontgrade Gaisler AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -1535,7 +1535,7 @@ static void __exit grspwu_exit (void)
 module_init(grspwu_init);
 module_exit(grspwu_exit);
 
-MODULE_AUTHOR("Cobham Gaisler AB.");
-MODULE_DESCRIPTION("Cobham Gaisler GRSPW SpaceWire Driver");
+MODULE_AUTHOR("Frontgrade Gaisler AB.");
+MODULE_DESCRIPTION("Frontgrade Gaisler GRSPW SpaceWire Driver");
 MODULE_LICENSE("GPL");
 MODULE_ALIAS("platform:grlib-grspwu");
